/*
 * himview.h
 * 
 * History Image Viewer prototypes header. 
 * 
 * Copyright (c) 2004--2005 by Wolfgang Wieser (wwieser@gmx.de)
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */


#ifndef _HISTORY_IMAGE_VIEWER_H_
#define _HISTORY_IMAGE_VIEWER_H_ 1

#include <qstring.h>
#include <qwidget.h>
#include <qpainter.h>
#include <qimage.h>
#include <qapplication.h>
#include <qpopupmenu.h>

#include "linkedlist.h"


extern QApplication *qapp;
extern int def_hist_size;

class HistoryViewWidget : public QWidget
{
	public:
		struct HEntry : LinkedListBase<HEntry>
		{
			QString file;
			QImage *img;
			
			HEntry(const QString &file);
			~HEntry();
		};
	private:
		// Number of open windows: 
		static int n_open_windows;
		
	private:
		QPainter pnt;
		
		// List of image entries: 
		// Newest entries at the end. 
		LinkedList<HEntry> hl;
		// Actively displayed entry or NULL. 
		HEntry *active;
		// (Max) history size: 
		int hist_size;
		
		// Popup menu with right mouse: 
		QPopupMenu *menu;
		QPopupMenu *switch_to_menu;
		
		void _CreateMenu();
		void _DisplayCaption();
		void _DisplayActiveImage();
		void _CheckExpire();
		void _SwitchHist(int dir);
		void _NewCopyImage();
		void _ImageOpen();
		void _ImageSaveAs();
		
		void closeEvent(QCloseEvent *);
		void keyPressEvent(QKeyEvent *ev);
		void mousePressEvent(QMouseEvent *ev);
		void paintEvent(QPaintEvent *ev);
	public:
		// Pass empty string as file for no file. 
		HistoryViewWidget(const QString &file,
			QWidget *parent=NULL, const char *name=NULL,WFlags f=0);
		~HistoryViewWidget();
		
		// Load an image file: 
		int LoadFile(const QString &file);
		// Re-load active file: 
		void Reload(bool move_hist,bool atend);
		// Close and delete self: 
		void Close();
		// Delete image: 
		void DeleteImage(bool all);
};

#endif  /* _HISTORY_IMAGE_VIEWER_H_ */
