/*
 * main.cc
 * 
 * History Image Viewer main routine. 
 * 
 * Copyright (c) 2004--2005 by Wolfgang Wieser (wwieser@gmx.de)
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#include "himview.h"

#include <string.h>
#include <stdlib.h>

#define VERSION "0.4"


// Global data: 
QApplication *qapp=NULL;
int def_hist_size=10;

int main(int argc,char **arg)
{
	QApplication qapp(argc,arg);
	::qapp=&qapp;
	
	// Process options: 
	for(int i=1; i<argc; i++)
	{
		if(*arg[i]=='-')
		{
			if(!strcmp(arg[i],"-"))
			{ /* Ignore here. */ }
			else if(!strcmp(arg[i],"-help") || !strcmp(arg[i],"--help"))
			{
				fprintf(stderr,
					"USAGE: himview [options] [file...]\n"
					"Options:\n"
					"   --help  print this\n"
					"   -h=NUM  set history size (default: 10)\n"
					"Standard Qt options (-display, -fn, ... accepted)\n"
					"\n"
					"file...: list of PNG/JPEG files to open; use a single '-' to\n"
					"         have following images opened in a new window\n"
					"\n"
					"Try 'h' in a window for help on interactive commands.\n"
					"\n"
					"HIMView -- HIstory IMage VIEWer, version %s\n"
					"           Copyright (c) 2004--2005 by Wolfgang Wieser\n",
					VERSION);
				return(0);
			}
			else if(!strncmp(arg[i],"-h=",3))
			{
				def_hist_size=atoi(arg[i]+3);
				if(def_hist_size<1)  def_hist_size=10;
			}
			else
			{
				fprintf(stderr,"Illegal option \"%s\". Try himview --help\n");
				return(1);
			}
		}
	}
	
	// Open a widget: 
	HistoryViewWidget *hv=new HistoryViewWidget(NULL);
	
	// Load files if specified: 
	for(int i=1; i<argc; i++)
	{
		if(*arg[i]=='-')
		{
			if(!strcmp(arg[i],"-"))
			{
				hv->show();
				hv=new HistoryViewWidget(NULL);
			}
			// else: ignore
		}
		else
		{
			hv->LoadFile(arg[i]);
		}
	}
	
	//qapp.setMainWidget(hv);
	hv->show();
	
	int rv=qapp.exec();
	
	return(rv);
}
